@@ -40,7 +40,7 @@ with 'Lintian::Check';
 
 has only_conffiles => (is => 'rwp', default => 1);
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     # check if package contains non-conffiles
@@ -68,8 +68,7 @@ sub binary {
 
         # ignore if package contains no files
         return
-          if -z path($self->processable->groupdir)->child('md5sums')
-          ->stringify;
+          if -z path($self->processable->basedir)->child('md5sums')->stringify;
 
         $self->tag('no-md5sums-control-file')
           unless $self->only_conffiles;
