@@ -24,7 +24,7 @@ use warnings;
 use utf8;
 use autodie;
 
-use Carp;
+use Carp qw(croak);
 use Devel::Size qw(total_size);
 use File::Spec;
 use List::Compare;
@@ -43,8 +43,6 @@ use Lintian::Util qw(human_bytes);
 
 use constant EMPTY => q{};
 use constant SPACE => q{ };
-use constant HYPHEN => q{-};
-use constant SLASH => q{/};
 
 use Moo;
 use namespace::clean;
@@ -130,8 +128,6 @@ Hash with active jobs.
 
 =item C<saved_direct_reliants>
 
-=item C<saved_spelling_exceptions>
-
 =cut
 
 has pooldir => (is => 'rw', default => EMPTY);
@@ -150,10 +146,6 @@ has processing_end => (is => 'rw', default => EMPTY);
 has cache => (is => 'rw', default => sub { {} });
 has profile => (is => 'rw', default => sub { {} });
 
-has saved_direct_dependencies => (is => 'rw', default => sub { {} });
-has saved_direct_reliants => (is => 'rw', default => sub { {} });
-has saved_spelling_exceptions => (is => 'rw', default => sub { {} });
-
 =item add_processable_from_file
 
 =cut
@@ -214,8 +206,8 @@ sub process {
     my @processables = $self->get_processables;
     for my $processable (@processables) {
 
-        path($processable->groupdir)->mkpath
-          unless -e $processable->groupdir;
+        path($processable->basedir)->mkpath
+          unless -e $processable->basedir;
 
         symlink($processable->path, $processable->link)
           unless -l $processable->link;
@@ -247,7 +239,7 @@ sub process {
         my $declared_overrides;
 
         $OUTPUT->debug_msg(1,
-            'Base directory for group: ' . $processable->groupdir);
+            'Base directory for processable: ' . $processable->basedir);
 
         unless ($option->{'no-override'}) {
 
@@ -319,14 +311,17 @@ sub process {
             my $raw_res = tv_interval($timer);
 
             if ($err) {
-                print STDERR $err;
-                print STDERR "internal error: cannot run $checkname check",
-                  " on package $procid\n";
-                $OUTPUT->warning("skipping check of $procid");
+                my $message = $err;
+                $message
+                  .= "warning: cannot run $checkname check on package $procid\n";
+                $message .= "skipping check of $procid\n";
+                warn $message;
+
                 $success = 0;
 
                 next;
             }
+
             my $tres = sprintf('%.3fs', $raw_res);
             $OUTPUT->debug_msg(1,
                 "Check script $checkname for $procid done ($tres)");
@@ -631,6 +626,8 @@ Note: Self-dependencies (if any) are I<not> included in the result.
 
 =cut
 
+has saved_direct_dependencies => (is => 'rw', default => sub { {} });
+
 sub direct_dependencies {
     my ($self, $processable) = @_;
 
@@ -681,6 +678,8 @@ Note: Self-dependencies (if any) are I<not> included in the result.
 
 =cut
 
+has saved_direct_reliants => (is => 'rw', default => sub { {} });
+
 sub direct_reliants {
     my ($self, $processable) = @_;
 
@@ -727,30 +726,28 @@ Example: Package alot-doc (#687464)
 
 =cut
 
-sub spelling_exceptions {
-    my ($self) = @_;
+has spelling_exceptions => (
+    is => 'rw',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
 
-    return $self->saved_spelling_exceptions
-      if keys %{$self->saved_spelling_exceptions};
+        my %exceptions;
 
-    my %exceptions;
+        for my $processable ($self->get_processables) {
 
-    foreach my $processable ($self->get_processables) {
+            my @names = ($processable->name, $processable->source);
+            push(@names, $processable->debian_control->installables)
+              if $processable->type eq 'source';
 
-        my @names = ($processable->name, $processable->source);
-        push(@names, $processable->debian_control->installables)
-          if $processable->type eq 'source';
-
-        foreach my $name (@names) {
-            $exceptions{$name} = 1;
-            $exceptions{$_} = 1 for split m/-/, $name;
+            foreach my $name (@names) {
+                $exceptions{$name} = 1;
+                $exceptions{$_} = 1 for split m/-/, $name;
+            }
         }
-    }
 
-    $self->saved_spelling_exceptions(\%exceptions);
-
-    return $self->saved_spelling_exceptions;
-}
+        return \%exceptions;
+    });
 
 =back
 
