@@ -22,10 +22,11 @@ use warnings;
 use utf8;
 use autodie;
 
+use IO::Uncompress::Gunzip qw(gunzip $GunzipError);
 use Path::Tiny;
 
 use Lintian::Architecture qw(:all);
-use Lintian::Util qw($PKGNAME_REGEX gunzip_file is_ancestor_of);
+use Lintian::Util qw($PKGNAME_REGEX is_ancestor_of);
 
 use constant EMPTY => q{};
 
@@ -56,11 +57,11 @@ Lintian::Processable::Overrides provides an interface to package data for overri
 sub add_overrides {
     my ($self) = @_;
 
-    my $unpackedpath = path($self->groupdir)->child('unpacked')->stringify;
+    my $unpackedpath = path($self->basedir)->child('unpacked')->stringify;
     die "No unpacked data in $unpackedpath"
       unless -d $unpackedpath;
 
-    my $overridepath = path($self->groupdir)->child('override')->stringify;
+    my $overridepath = path($self->basedir)->child('override')->stringify;
     unlink($overridepath)
       if -e $overridepath;
 
@@ -96,7 +97,9 @@ sub add_overrides {
       unless is_ancestor_of($unpackedpath, $packageoverridepath);
 
     if ($packageoverridepath =~ /\.gz$/) {
-        gunzip_file($packageoverridepath, $overridepath);
+        gunzip($packageoverridepath => $overridepath)
+          or die "gunzip $packageoverridepath failed: $GunzipError";
+
     } else {
         link($packageoverridepath, $overridepath);
     }
@@ -126,7 +129,7 @@ sub overrides {
     my @comments;
     my %previous;
 
-    my $path = path($self->groupdir)->child('override')->stringify;
+    my $path = path($self->basedir)->child('override')->stringify;
 
     return
       unless -f $path;
